[openssl-commits] [openssl] master update

kaduk at mit.edu kaduk at mit.edu
Tue May 1 16:32:16 UTC 2018


The branch master has been updated
       via  c4fa1f7fc016919a5b3d4ea2aa66c77e0cc40c9d (commit)
      from  0e5c1a66f7911352a4db3bda2293b91858b9f33c (commit)


- Log -----------------------------------------------------------------
commit c4fa1f7fc016919a5b3d4ea2aa66c77e0cc40c9d
Author: Benjamin Kaduk <bkaduk at akamai.com>
Date:   Mon Apr 16 07:32:02 2018 -0500

    Fix regression with session cache use by clients
    
    Commit d316cdcf6d8d6934663278145fe0a8191e14a8c5 introduced some extra
    checks into the session-cache update procedure, intended to prevent
    the caching of sessions whose resumption would lead to a handshake
    failure, since if the server is authenticating the client, there needs to
    be an application-set "session id context" to match up to the authentication
    context.  While that change is effective for its stated purpose, there
    was also some collatoral damage introduced along with the fix -- clients
    that set SSL_VERIFY_PEER are not expected to set an sid_ctx, and so
    their usage of session caching was erroneously denied.
    
    Fix the scope of the original commit by limiting it to only acting
    when the SSL is a server SSL.
    
    Reviewed-by: Matt Caswell <matt at openssl.org>
    (Merged from https://github.com/openssl/openssl/pull/5967)

-----------------------------------------------------------------------

Summary of changes:
 ssl/ssl_lib.c | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/ssl/ssl_lib.c b/ssl/ssl_lib.c
index 1e24f84..2a57831 100644
--- a/ssl/ssl_lib.c
+++ b/ssl/ssl_lib.c
@@ -3336,12 +3336,13 @@ void ssl_update_cache(SSL *s, int mode)
     /*
      * If sid_ctx_length is 0 there is no specific application context
      * associated with this session, so when we try to resume it and
      * SSL_VERIFY_PEER is requested, we have no indication that this is
      * actually a session for the proper application context, and the
      * *handshake* will fail, not just the resumption attempt.
      * Do not cache these sessions that are not resumable.
      */
-    if (s->session->sid_ctx_length == 0
+    if (s->server && s->session->sid_ctx_length == 0
             && (s->verify_mode & SSL_VERIFY_PEER) != 0)
         return;
 
@@ -3336,12 +3336,13 @@ void ssl_update_cache(SSL *s, int mode)
      * If sid_ctx_length is 0 there is no specific application context
      * associated with this session, so when we try to resume it and
-     * SSL_VERIFY_PEER is requested, we have no indication that this is
-     * actually a session for the proper application context, and the
-     * *handshake* will fail, not just the resumption attempt.
-     * Do not cache these sessions that are not resumable.
+     * SSL_VERIFY_PEER is requested to verify the client identity, we have no
+     * indication that this is actually a session for the proper application
+     * context, and the *handshake* will fail, not just the resumption attempt.
+     * Do not cache (on the server) these sessions that are not resumable
+     * (clients can set SSL_VERIFY_PEER without needing a sid_ctx set).
      */


More information about the openssl-commits mailing list